@@ -95,12 +95,19 @@ static gpointer		get_typed_property_data	  (Display     *xdisplay,
 						   guint        expected_format);
 static gboolean		wm_protocol_check_support (Window     xwin,
 						   Atom       check_atom);
-static gboolean		send_client_message_32	  (Window     recipient,
+static gboolean		send_client_message_2L	  (Window     recipient,
 						   Window     event_window,
 						   Atom       message_type,
 						   long       event_mask,
-						   guint      n_longs,
-						   ...);
+						   glong      long1,
+						   glong      long2);
+static gboolean		send_client_message_3L	  (Window     recipient,
+						   Window     event_window,
+						   Atom       message_type,
+						   long       event_mask,
+						   glong      long1,
+						   glong      long2,
+						   glong      long3);
 static void 		get_task_root_and_frame   (GwmhTask    *task);
 static GdkWindow*	gdk_window_ref_from_xid	  (Window       xwin);
 static guint            gwmh_property_atom2info   (Atom         atom,
@@ -109,7 +116,7 @@ static void		gwmh_task_queue_full	  (GwmhTask          *task,
 						   GwmhTaskInfoMask   imask,
 						   GwmhTaskInfoMask   notify_mask);
 static void		gwmh_desk_update	  (GwmhDeskInfoMask   imask);
-static void		gwmh_task_update	  (GwmhTask          *task,
+static gboolean		gwmh_task_update	  (GwmhTask          *task,
 						   GwmhTaskInfoMask   imask,
 						   gboolean           skip_notify);
 static void		gwmh_desk_notify	  (GwmhDeskInfoMask   imask);
@@ -118,15 +125,15 @@ static void		gwmh_task_notify	  (GwmhTask	     *task,
 						   GwmhTaskInfoMask   imask);
 static GwmhTask*	task_new		  (GdkWindow	      *gdkwindow);
 static void		task_delete		  (GwmhTask	     *task);
-static gboolean		client_list_sync	  (Window            *xwindows,
-						   guint              n_xwindows);
+static gboolean		client_list_sync	  (guint32           *xwindows_ids,
+						   guint              n_ids);
 static GdkFilterReturn	task_event_monitor	  (GdkXEvent         *gdk_xevent,
 						   GdkEvent          *event,
 						   gpointer           task_pointer);
 static GdkFilterReturn	root_event_monitor	  (GdkXEvent         *gdk_xevent,
 						   GdkEvent          *event,
 						   gpointer           gdk_root);
-static gpointer		hack_a_client_list	  (Display           *display,
+static guint32*		hack_a_client_list	  (Display           *display,
 						   Window             xroot,
 						   guint             *_n_clients);
 
@@ -155,6 +162,7 @@ static GwmhDesk         gwmh_desk = {
   FALSE /* unified_area */,
 };
 static gboolean		gwmh_hack_think_unified_area = FALSE;
+static gboolean		gwmh_hack_violate_client_msg = TRUE;
 
 
 /* --- functions --- */
@@ -386,6 +394,15 @@ get_typed_property_data (Display *xdisplay,
 	{
 	case 32:
 	  *size_p = nitems_return * 4;
+	  if (sizeof (gulong) == 8)
+	    {
+	      guint32 i, *mem = g_malloc0 (*size_p + 1);
+	      gulong *prop_longs = (gulong*) prop_data;
+
+	      for (i = 0; i < *size_p / 4; i++)
+		mem[i] = prop_longs[i];
+	      data = mem;
+	    }
 	  break;
 	case 16:
 	  *size_p = nitems_return * 2;
@@ -398,7 +415,7 @@ get_typed_property_data (Display *xdisplay,
 		     format_returned);
 	  break;
 	}
-      if (*size_p)
+      if (!data && *size_p)
 	{
 	  guint8 *mem = g_malloc (*size_p + 1);
 
@@ -418,18 +435,18 @@ static gboolean
 wm_protocol_check_support (Window xwin,
 			   Atom   check_atom)
 {
-  Atom *protocols, *xdata = NULL;
-  gpointer gdata = NULL;
-  int n_protocols = 0;
+  Atom *pdata = NULL;
+  guint32 *gdata = NULL;
+  int n_pids = 0;
   gboolean is_supported = FALSE;
-  guint i;
+  guint i, n_gids = 0;
 
   gdk_error_trap_push ();
 
   if (!XGetWMProtocols (GDK_DISPLAY (),
 			xwin,
-			&xdata,
-			&n_protocols))
+			&pdata,
+			&n_pids))
     {
       gint size = 0;
 
@@ -438,49 +455,62 @@ wm_protocol_check_support (Window xwin,
 				       XA_WM_PROTOCOLS,
 				       XA_WM_PROTOCOLS,
 				       &size, 32);
-      n_protocols = size / 4;
+      n_gids = size / 4;
     }
 
   gdk_error_trap_pop ();
 
-  protocols = xdata ? xdata : gdata;
-  for (i = 0; i < n_protocols; i++)
-    if (protocols[i] == check_atom)
+  for (i = 0; i < n_pids; i++)
+    if (pdata[i] == check_atom)
       {
 	is_supported = TRUE;
 	break;
       }
-  if (xdata)
-    XFree (xdata);
+  if (pdata)
+    XFree (pdata);
+  if (!is_supported)
+    for (i = 0; i < n_gids; i++)
+      if (gdata[i] == check_atom)
+        {
+	  is_supported = TRUE;
+	  break;
+        }
   g_free (gdata);
 
   return is_supported;
 }
 
 static gboolean
-send_client_message_32 (Window recipient,
+send_client_message_2L (Window recipient,
 			Window event_window,
 			Atom   message_type,
 			long   event_mask,
-			guint  n_longs,
-			...)
+			glong  long1,
+			glong  long2)
+{
+  return send_client_message_3L (recipient, event_window, message_type, event_mask, long1, long2, 0);
+}
+
+static gboolean
+send_client_message_3L (Window recipient,
+			Window event_window,
+			Atom   message_type,
+			long   event_mask,
+			glong  long1,
+			glong  long2,
+			glong  long3)
 {
   XEvent xevent = { 0, };
-  guint i = 0;
-  va_list var_args;
 
-  g_return_val_if_fail (n_longs < 6, FALSE);
-
-  va_start (var_args, n_longs);
+  /* g_return_val_if_fail (n_longs < 6, FALSE); */
 
   xevent.type = ClientMessage;
   xevent.xclient.window = event_window;
   xevent.xclient.message_type = message_type;
   xevent.xclient.format = 32;
-  while (n_longs--)
-    xevent.xclient.data.l[i++] = va_arg (var_args, gint32);
-
-  va_end (var_args);
+  xevent.xclient.data.l[0] = long1;
+  xevent.xclient.data.l[1] = long2;
+  xevent.xclient.data.l[2] = long3;
 
   gdk_error_trap_push ();
 
@@ -982,21 +1012,21 @@ gwmh_desk_update (GwmhDeskInfoMask imask)
   if (imask & GWMH_DESK_INFO_CLIENT_LIST)
     {
       gint n_tasks, size = 0;
-      Window *task_data;
+      guint32 *task_ids;
 
       if (!gwmh_gnome_wm_win)
-	task_data = hack_a_client_list (xdisplay, xwindow, &n_tasks);
+	task_ids = hack_a_client_list (xdisplay, xwindow, &n_tasks);
       else
 	{
-	  task_data = get_typed_property_data (xdisplay, xwindow,
-					       GWMHA_WIN_CLIENT_LIST,
-					       XA_CARDINAL,
-					       &size, 32);
+	  task_ids = get_typed_property_data (xdisplay, xwindow,
+					      GWMHA_WIN_CLIENT_LIST,
+					      XA_CARDINAL,
+					      &size, 32);
 	  n_tasks = size / 4;
 	}
-      if (client_list_sync (task_data, n_tasks))
+      if (client_list_sync (task_ids, n_tasks))
 	ichanges |= GWMH_DESK_INFO_CLIENT_LIST;
-      g_free (task_data);
+      g_free (task_ids);
     }
   
   gdk_error_trap_pop ();
@@ -1029,7 +1059,7 @@ gwmh_desk_update (GwmhDeskInfoMask imask)
     gwmh_desk_notify (ichanges);
 }
 
-static void
+static gboolean
 gwmh_task_update (GwmhTask        *task,
 		  GwmhTaskInfoMask imask,
 		  gboolean         skip_notify)
@@ -1083,8 +1113,11 @@ gwmh_task_update (GwmhTask        *task,
       get_task_root_and_frame (task);
       if (!task->xframe || !task->sroot)
 	{
-	  task_delete (task);
-	  return;
+	  /* eek, that's ugly, we need to get rid of this task as
+	   * soon as possible, but *not* right here.
+	   */
+	  gwmh_desk_queue_update (GWMH_DESK_INFO_CLIENT_LIST);
+	  return FALSE;
 	}
       if (task->xframe != xframe ||
 	  (task->sroot ? GSTC_PARENT_XWINDOW (task->sroot) : 0) != !xroot)
@@ -1337,6 +1370,8 @@ gwmh_task_update (GwmhTask        *task,
   
   if (!skip_notify && ichanges)
     gwmh_task_notify (task, GWMH_NOTIFY_INFO_CHANGED, ichanges);
+
+  return TRUE;
 }
 
 static gboolean
@@ -1601,12 +1636,19 @@ task_new (GdkWindow *window)
   /* gwmh_task_update () will do this for us:
    * get_task_root_and_frame (task);
    */
-  gwmh_task_update (task, GWMH_TASK_INFO_ALL, TRUE);
+  if (gwmh_task_update (task, GWMH_TASK_INFO_ALL, TRUE))
+    {
+      gwmh_task_notify (task, GWMH_NOTIFY_NEW, 0);
+      gwmh_task_update (task, 0, FALSE);
 
-  gwmh_task_notify (task, GWMH_NOTIFY_NEW, 0);
-  gwmh_task_update (task, 0, FALSE);
+      return task;
+    }
+  else
+    {
+      task_delete (task);
 
-  return task;
+      return NULL;
+    }
 }
 
 static void
@@ -1663,12 +1705,24 @@ task_delete (GwmhTask *task)
   gwmh_desk.client_list = g_list_remove (gwmh_desk.client_list, task);
   g_free (task->name);
   task->name = "DELETED";
+
+  if (g_list_find (gwmh_desk.client_list, task))
+    {
+      g_warning ("deleted task still in client_list\n"); /* FIXME */
+      g_assert_not_reached ();
+    }
+  if (g_slist_find (gwmh_task_queue, task))
+    {
+      g_warning ("deleted task still in queue\n"); /* FIXME */
+      g_assert_not_reached ();
+    }
+    
   g_free (task);
 }
 
 static gboolean
-client_list_sync (Window *xwindows,
-		  guint   n_xwindows)
+client_list_sync (guint32 *xwindow_ids,
+		  guint    n_ids)
 {
   guint i;
   GList *node, *client_list = NULL;
@@ -1682,11 +1736,11 @@ client_list_sync (Window *xwindows,
       
       node = node->next;
 
-      for (i = 0; i < n_xwindows; i++)
-	if (xwindows[i] == task->xwin)
+      for (i = 0; i < n_ids; i++)
+	if (xwindow_ids[i] == task->xwin)
 	  {
-	    n_xwindows--;
-	    xwindows[i] = xwindows[n_xwindows];
+	    n_ids--;
+	    xwindow_ids[i] = xwindow_ids[n_ids];
 	    client_list = g_list_prepend (client_list, task);
 	    found_client = TRUE;
 	    break;
@@ -1698,19 +1752,24 @@ client_list_sync (Window *xwindows,
 	}
     }
 
-  for (i = 0; i < n_xwindows; i++)
+  for (i = 0; i < n_ids; i++)
     {
-      GdkWindow *window = gdk_window_ref_from_xid (xwindows[i]);
+      GdkWindow *window = gdk_window_ref_from_xid (xwindow_ids[i]);
 
       if (window)
 	{
-	  client_list = g_list_prepend (client_list,
-					task_new (window));
-	  clients_changed = TRUE;
+	  GwmhTask *task = task_new (window);
+
+	  if (task)
+	    {
+	      client_list = g_list_prepend (client_list, task);
+	      clients_changed = TRUE;
+	    }
 	  gdk_window_unref (window);
 	}
     }
 
+  g_assert (g_list_length (gwmh_desk.client_list) == g_list_length (client_list)); /* FIXME */
   if (clients_changed)
     {
       g_list_free (gwmh_desk.client_list);
@@ -1803,10 +1862,10 @@ gwmh_task_close (GwmhTask *task)
   can_delete = wm_protocol_check_support (task->xwin, XA_WM_DELETE_WINDOW);
 
   if (can_delete)
-    can_delete = send_client_message_32 (task->xwin, task->xwin,
+    can_delete = send_client_message_2L (task->xwin, task->xwin,
 					 XA_WM_PROTOCOLS,
 					 0,
-					 2, XA_WM_DELETE_WINDOW, CurrentTime);
+					 XA_WM_DELETE_WINDOW, CurrentTime);
 
   return can_delete;
 }
@@ -1827,14 +1886,13 @@ gwmh_task_deiconify (GwmhTask *task)
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_ICONIFIED, FALSE);
-
-  if (GWMH_TASK_ICONIFIED (task))
+  if (gwmh_task_update (task, GWMH_TASK_INFO_ICONIFIED, FALSE) &&
+      GWMH_TASK_ICONIFIED (task))
     {
       gdk_error_trap_push ();
-
+      
       XMapWindow (GDK_DISPLAY (), task->xwin);
-
+      
       gwmh_sync ();
       gdk_error_trap_pop ();
     }
@@ -1845,13 +1903,14 @@ gwmh_task_focus (GwmhTask *task)
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_FOCUSED, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_FOCUSED, FALSE))
+    return;
 
   if (wm_protocol_check_support (task->xwin, XA_WM_TAKE_FOCUS))
-    send_client_message_32 (task->xwin, task->xwin,
+    send_client_message_2L (task->xwin, task->xwin,
 			    XA_WM_PROTOCOLS,
 			    0,
-			    2, XA_WM_TAKE_FOCUS, CurrentTime);
+			    XA_WM_TAKE_FOCUS, CurrentTime);
 
   if (!GWMH_TASK_FOCUSED (task))
     {
@@ -1869,18 +1928,19 @@ gwmh_task_show (GwmhTask *task)
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task,
-		    (GWMH_TASK_INFO_ICONIFIED |
-		     GWMH_TASK_INFO_FOCUSED |
-		     GWMH_TASK_INFO_GSTATE),
-		    FALSE);
+  if (!gwmh_task_update (task,
+			 (GWMH_TASK_INFO_ICONIFIED |
+			  GWMH_TASK_INFO_FOCUSED |
+			  GWMH_TASK_INFO_GSTATE),
+			 FALSE))
+    return;
 
   if (!GWMH_TASK_SKIP_FOCUS (task) &&
       wm_protocol_check_support (task->xwin, XA_WM_TAKE_FOCUS))
-    send_client_message_32 (task->xwin, task->xwin,
+    send_client_message_2L (task->xwin, task->xwin,
 			    XA_WM_PROTOCOLS,
 			    0,
-			    2, XA_WM_TAKE_FOCUS, CurrentTime);
+			    XA_WM_TAKE_FOCUS, CurrentTime);
 
   gdk_error_trap_push ();
 
@@ -1890,12 +1950,10 @@ gwmh_task_show (GwmhTask *task)
     XSetInputFocus (GDK_DISPLAY (), task->xwin, RevertToPointerRoot, CurrentTime);
   XRaiseWindow (GDK_DISPLAY (), task->xwin);
   if (GWMH_TASK_SHADED (task))
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+    send_client_message_3L (GDK_ROOT_WINDOW (), task->xwin,
 			    GWMHA_WIN_STATE,
 			    SubstructureNotifyMask,
-			    3,
-			    GWMH_STATE_SHADED, 0,
-			    CurrentTime);
+			    GWMH_STATE_SHADED, 0, CurrentTime);
   
   gwmh_sync ();
   
@@ -1921,13 +1979,14 @@ gwmh_task_set_gstate_flags (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_GSTATE, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_GSTATE, FALSE))
+    return;
 
   if ((GWMH_TASK_GSTATE (task) & flags) != flags)
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+    send_client_message_3L (GDK_ROOT_WINDOW (), task->xwin,
 			    GWMHA_WIN_STATE,
 			    SubstructureNotifyMask,
-			    3, flags, flags, CurrentTime);
+			    flags, flags, CurrentTime);
 }
 
 void
@@ -1936,13 +1995,14 @@ gwmh_task_unset_gstate_flags (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_GSTATE, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_GSTATE, FALSE))
+    return;
 
   if (GWMH_TASK_GSTATE (task) & flags)
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+    send_client_message_3L (GDK_ROOT_WINDOW (), task->xwin,
 			    GWMHA_WIN_STATE,
 			    SubstructureNotifyMask,
-			    3, flags, 0, CurrentTime);
+			    flags, 0, CurrentTime);
 }
 
 void
@@ -1951,13 +2011,14 @@ gwmh_task_set_ghint_flags (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_GHINTS, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_GHINTS, FALSE))
+    return;
 
   if ((GWMH_TASK_GHINTS (task) & flags) != flags)
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+    send_client_message_3L (GDK_ROOT_WINDOW (), task->xwin,
 			    GWMHA_WIN_HINTS,
 			    SubstructureNotifyMask,
-			    3, flags, flags, CurrentTime);
+			    flags, flags, CurrentTime);
 }
 
 void
@@ -1966,13 +2027,14 @@ gwmh_task_unset_ghint_flags (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_GHINTS, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_GHINTS, FALSE))
+    return;
 
   if (GWMH_TASK_GHINTS (task) & flags)
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+    send_client_message_3L (GDK_ROOT_WINDOW (), task->xwin,
 			    GWMHA_WIN_HINTS,
 			    SubstructureNotifyMask,
-			    3, flags, 0, CurrentTime);
+			    flags, 0, CurrentTime);
 }
 
 void
@@ -1981,13 +2043,14 @@ gwmh_task_set_app_state (GwmhTask        *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_APP_STATE, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_APP_STATE, FALSE))
+    return;
 
   if (GWMH_TASK_APP_STATE (task) != app_state)
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+    send_client_message_2L (GDK_ROOT_WINDOW (), task->xwin,
 			    GWMHA_WIN_APP_STATE,
 			    SubstructureNotifyMask,
-			    2, app_state, CurrentTime);
+			    app_state, CurrentTime);
 }
 
 void
@@ -2018,31 +2081,38 @@ gwmh_task_get_mini_icon (GwmhTask   *task,
 				      &size,
 				      32);
 
-  if (atomdata)
-    {
-      /* Get icon size and depth */
-      XGetGeometry (xdisplay, (Drawable)atomdata[0], &root, &x, &y, 
-		    &width, &height, &b, &depth);
-      
-      /* Create a new GdkPixmap and copy the mini icon pixmap to it */
-      *pixmap = gdk_pixmap_new (NULL, 16, 16, depth);
-      gc = gdk_gc_new (*pixmap);
-      gc_private = (GdkGCPrivate*) gc;
-      private = (GdkPixmapPrivate*) *pixmap;
-      XCopyArea (private->xdisplay, atomdata[0], private->xwindow, gc_private->xgc,
-		 0, 0, width, height, 0, 0);
-      gdk_gc_destroy (gc);
-      
-      /* Create a new GdkBitmap and copy the mini icon mask to it */
-      *mask = gdk_pixmap_new (NULL, 16, 16, 1);
-      gc = gdk_gc_new (*mask);
-      gc_private = (GdkGCPrivate*) gc;
-      private = (GdkPixmapPrivate*) (*mask);
-      XCopyArea (private->xdisplay, atomdata[1], private->xwindow, gc_private->xgc,
-		 0, 0, 16, 16, 0, 0);
-      gdk_gc_destroy (gc);
-      g_free (atomdata);
-    }
+  if (!atomdata) {
+    *pixmap = NULL;
+    return;
+  }
+
+  if (!atomdata[0]) {
+    *pixmap = NULL;
+    return;
+  }
+
+  /* Get icon size and depth */
+  XGetGeometry (xdisplay, (Drawable)atomdata[0], &root, &x, &y, 
+		&width, &height, &b, &depth);
+  
+  /* Create a new GdkPixmap and copy the mini icon pixmap to it */
+  *pixmap = gdk_pixmap_new (NULL, 16, 16, depth);
+  gc = gdk_gc_new (*pixmap);
+  gc_private = (GdkGCPrivate*) gc;
+  private = (GdkPixmapPrivate*) *pixmap;
+  XCopyArea (private->xdisplay, atomdata[0], private->xwindow, gc_private->xgc,
+	     0, 0, width, height, 0, 0);
+  gdk_gc_destroy (gc);
+  
+  /* Create a new GdkBitmap and copy the mini icon mask to it */
+  *mask = gdk_pixmap_new (NULL, 16, 16, 1);
+  gc = gdk_gc_new (*mask);
+  gc_private = (GdkGCPrivate*) gc;
+  private = (GdkPixmapPrivate*) (*mask);
+  XCopyArea (private->xdisplay, atomdata[1], private->xwindow, gc_private->xgc,
+	     0, 0, 16, 16, 0, 0);
+  gdk_gc_destroy (gc);
+  g_free (atomdata);
 }
 
 void
@@ -2051,13 +2121,14 @@ gwmh_task_set_layer (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_LAYER, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_LAYER, FALSE))
+    return;
 
   if (task->layer != layer)
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+    send_client_message_2L (GDK_ROOT_WINDOW (), task->xwin,
 			    GWMHA_WIN_LAYER,
 			    SubstructureNotifyMask,
-			    2, layer, CurrentTime);
+			    layer, CurrentTime);
 }
 
 void
@@ -2068,7 +2139,8 @@ gwmh_task_set_area (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_DESKTOP | GWMH_TASK_INFO_AREA, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_DESKTOP | GWMH_TASK_INFO_AREA, FALSE))
+    return;
   
   if (desktop >= gwmh_desk.n_desktops ||
       harea >= gwmh_desk.n_hareas ||
@@ -2081,7 +2153,10 @@ gwmh_task_set_area (GwmhTask *task,
   gwmh_sync ();
   gwmh_freeze_syncs ();
 
-  if (1) /* ugly hack for buggy window managers */
+  /* ugly hack for buggy window managers
+   * that violate the spec and expect us to modify properties directly
+   */
+  if (gwmh_hack_violate_client_msg)
     {
       long data[2];
       
@@ -2099,17 +2174,19 @@ gwmh_task_set_area (GwmhTask *task,
 
       gdk_error_trap_pop ();
     }
-
-  if (desktop != task->desktop)
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
-			    GWMHA_WIN_WORKSPACE,
-			    SubstructureNotifyMask,
-			    2, desktop, CurrentTime);
-  send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
-			  GWMHA_WIN_AREA,
-			  SubstructureNotifyMask,
-			  3, harea, varea, CurrentTime);
-
+  else
+    {
+      if (desktop != task->desktop)
+	send_client_message_2L (GDK_ROOT_WINDOW (), task->xwin,
+				GWMHA_WIN_WORKSPACE,
+				SubstructureNotifyMask,
+				desktop, CurrentTime);
+      send_client_message_3L (GDK_ROOT_WINDOW (), task->xwin,
+			      GWMHA_WIN_AREA,
+			      SubstructureNotifyMask,
+			      harea, varea, CurrentTime);
+    }
+  
   gwmh_thaw_syncs ();
 }
 
@@ -2119,12 +2196,14 @@ gwmh_task_set_desktop (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_DESKTOP, FALSE);
-  
-  if (desktop >= gwmh_desk.n_desktops || task->desktop == desktop)
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_DESKTOP, FALSE) ||
+      desktop >= gwmh_desk.n_desktops || task->desktop == desktop)
     return;
   
-  if (1) /* ugly hack for buggy window managers */
+  /* ugly hack for buggy window managers
+   * that violate the spec and expect us to modify properties directly
+   */
+  if (gwmh_hack_violate_client_msg)
     {
       long data[2];
       
@@ -2134,14 +2213,14 @@ gwmh_task_set_desktop (GwmhTask *task,
       if (desktop != task->desktop)
 	XChangeProperty (GDK_DISPLAY (), task->xwin, GWMHA_WIN_WORKSPACE,
 			 XA_CARDINAL, 32, PropModeReplace, (unsigned char*) data, 1);
-
+      
       gdk_error_trap_pop ();
     }
-
-  send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
-			  GWMHA_WIN_WORKSPACE,
-			  SubstructureNotifyMask,
-			  2, desktop, CurrentTime);
+  else
+    send_client_message_2L (GDK_ROOT_WINDOW (), task->xwin,
+			    GWMHA_WIN_WORKSPACE,
+			    SubstructureNotifyMask,
+			    desktop, CurrentTime);
 }
 
 GwmhDesk*
@@ -2178,16 +2257,18 @@ gwmh_desk_set_current_desktop (guint desktop)
       desktop == gwmh_desk.current_desktop)
     return;
 
-  send_client_message_32 (GDK_ROOT_WINDOW (), GDK_ROOT_WINDOW (),
+  send_client_message_2L (GDK_ROOT_WINDOW (), GDK_ROOT_WINDOW (),
 			  GWMHA_WIN_WORKSPACE,
 			  SubstructureNotifyMask,
-			  2, desktop, CurrentTime);
+			  desktop, CurrentTime);
 }
 
 void
-gwmh_desk_set_hack_values (gboolean unified_area)
+gwmh_desk_set_hack_values (gboolean unified_area,
+			   gboolean violate_client_msg)
 {
   gwmh_hack_think_unified_area = unified_area != FALSE;
+  gwmh_hack_violate_client_msg = violate_client_msg != FALSE;
 
   gwmh_desk_update (GWMH_DESK_INFO_N_AREAS);
 }
@@ -2211,14 +2292,14 @@ gwmh_desk_set_current_area (guint desktop,
   gwmh_sync ();
   gwmh_freeze_syncs ();
   if (desktop != gwmh_desk.current_desktop)
-    send_client_message_32 (GDK_ROOT_WINDOW (), GDK_ROOT_WINDOW (),
+    send_client_message_2L (GDK_ROOT_WINDOW (), GDK_ROOT_WINDOW (),
 			    GWMHA_WIN_WORKSPACE,
 			    SubstructureNotifyMask,
-			    2, desktop, CurrentTime);
-  send_client_message_32 (GDK_ROOT_WINDOW (), GDK_ROOT_WINDOW (),
+			    desktop, CurrentTime);
+  send_client_message_3L (GDK_ROOT_WINDOW (), GDK_ROOT_WINDOW (),
 			  GWMHA_WIN_AREA,
 			  SubstructureNotifyMask,
-			  3, harea, varea, CurrentTime);
+			  harea, varea, CurrentTime);
   gwmh_thaw_syncs ();
 }
 
@@ -2386,7 +2467,7 @@ find_input_client (Display *display,
   return xwindow;
 }
 
-static gpointer
+static guint32*
 hack_a_client_list (Display *display,
 		    Window   xroot,
 		    guint   *_n_clients)
