@@ -80,17 +80,15 @@ GnomeUIInfo sort_menu[] = {
 GnomeUIInfo help_menu[] = {
 /*	{ GNOME_APP_UI_HELP, NULL, NULL, NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },*/
-	  GNOMEUIINFO_MENU_ABOUT_ITEM(about_pressed_cb, NULL), 
-	{ GNOME_APP_UI_ENDOFINFO }
+	  GNOMEUIINFO_MENU_ABOUT_ITEM(about_pressed_cb, NULL),
+	  GNOMEUIINFO_END
 };
 GnomeUIInfo main_menu[] = {
-	{ GNOME_APP_UI_SUBTREE, N_("_File"), NULL, file_menu, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, NULL, 'F', GDK_MODIFIER_MASK, NULL },
+	GNOMEUIINFO_MENU_FILE_TREE (file_menu),
 	{ GNOME_APP_UI_SUBTREE, N_("_Sort"), NULL, sort_menu, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, NULL, 'S', GDK_MODIFIER_MASK, NULL },
-	{ GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, help_menu, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, NULL, 'H', GDK_MODIFIER_MASK, NULL },
-	{ GNOME_APP_UI_ENDOFINFO }
+	GNOMEUIINFO_MENU_HELP_TREE (help_menu),
+	GNOMEUIINFO_END
 };
 
 /* toolbar */
