@@ -68,6 +68,7 @@ static author authors[] = {
 	{ "Jochen Friedrich", "" },
 	{ "Adam Fritzler", "" },
 	{ "Michael Fulbright", "" },
+	{ "Christopher R. Gabriel",""},
 	{ "Mark Galassi", "" },
 	{ "Tony Gale", "" },
 	{ "Jeff Garzik", "" },
@@ -238,6 +239,7 @@ static author authors[] = {
 	{ "Sascha Ziemann", "" },
 	{ "Michael Zucchi", "<zucchi@zedzone.mmc.com.au>" },
 	{ "Jason van Zyl", "" },
+	{ "Gerg rdi", "<http://cactus.rulez.org>"},
 	{ "", "" },
 	{ N_("... and many more"), "" },
 	{ NULL, NULL }
