@@ -1,6 +1,7 @@
 /*
  * The GNOME terminal, using Michael Zucchi's zvt widget.
  * (C) 1998, 1999 The Free Software Foundation
+ * Copyright 2000 Helix Code, Inc.
  *
  * Authors: Miguel de Icaza (GNOME terminal)
  *          Erik Troan      (various configuration enhancements)
@@ -8,7 +9,8 @@
  *
  * Other contributors: George Lebl, Jeff Garzik, Jay Painter,
  * Christopher Blizzard, Jens Lautenbacher, Tom Tromey, Tristan Tarant,
- * Jonathan Blandford, Cody Russell, and Nat Friedman
+ * Jonathan Blandford, Cody Russell, Nat Friedman, Jacob Berkman, and
+ * John Harper
  */
 #include <config.h>
 #include <unistd.h>
@@ -23,6 +25,8 @@
 #include <gdk/gdkprivate.h>
 #include <gnome.h>
 #include <zvt/zvtterm.h>
+#include <orb/orbit.h>
+#include <libgnorba/gnorba.h>
 
 #include <X11/Xatom.h>
 
@@ -73,6 +77,7 @@ enum targets_enum {
 	TARGET_COLOR
 };
 
+
 struct terminal_config {
 	int keyboard_secured :1;		/* Does this terminal have the keyboard secured? */
         int bell             :1;                /* Do we want the bell? */
@@ -99,6 +104,7 @@ struct terminal_config {
 	int transparent;
 	int shaded;
 	int background_pixmap;
+	int terminal_id;			/* terminal id for this terminal */
 	char *pixmap_file;
         char *window_title;                     /* the window title */
 	char *wordclass;			/* select-by-word character class */
@@ -116,6 +122,13 @@ GtkWidget *initial_term = NULL;
 /* A list of all the open terminals */
 GList *terminals = 0;
 
+
+int use_terminal_factory   = FALSE;
+int start_terminal_factory = FALSE;
+
+/* current new terminal window id */
+static int terminal_id = 0;
+
 typedef struct {
 	GtkWidget *prop_win;
 	GtkWidget *blink_checkbox;
@@ -178,10 +191,7 @@ void paste_cmd            (GtkWidget *widget, ZvtTerm *term);
 void preferences_cmd      (GtkWidget *widget, ZvtTerm *term);
 void toggle_secure_keyboard_cmd (GtkWidget *w, ZvtTerm *term);
 
-static int popup_menu_cmd (ZvtTerm *term, GdkEventButton *event,
-			   GtkWidget *menu, GnomeUIInfo *uiinfo);
-
-GtkWidget *new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry);
+GtkWidget *new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry, int termid);
 GtkWidget *new_terminal     (GtkWidget *widget, ZvtTerm *term);
 
 static void parse_an_arg (poptContext state,
@@ -197,14 +207,20 @@ about_terminal_cmd (void)
         GtkWidget *about;
 
         const gchar *authors[] = {
-		"Zvt terminal widget: "
-		"    Michael Zucchi (zucchi@zedzone.mmc.com.au)",
-		"GNOME terminal: "
-		"    Miguel de Icaza (miguel@kernel.org)",
-		"    Erik Troan (ewt@redhat.com)",
+	     N_("Zvt terminal widget: "
+		"    Michael Zucchi (zucchi@zedzone.mmc.com.au)"),
+	     N_("GNOME terminal: "
+		"    Miguel de Icaza (miguel@kernel.org)"),
+	     N_("    Erik Troan (ewt@redhat.com)"),
 		NULL
 	};
 
+#ifdef ENABLE_NLS
+	authors[0]=_(authors[0]);
+	authors[1]=_(authors[1]);
+	authors[2]=_(authors[2]);
+#endif
+
         about = gnome_about_new (_("GNOME Terminal"), VERSION,
 				 "(C) 1998, 1999 the Free Software Foundation",
 				 authors,
@@ -216,6 +232,8 @@ about_terminal_cmd (void)
 static void
 close_app (GtkWidget *app)
 {
+	preferences_t *prefs;
+
         terminals = g_list_remove (terminals, app);
 
 	/* FIXME: this should free the config info for the window */
@@ -223,6 +241,10 @@ close_app (GtkWidget *app)
 	if (app == initial_term)
 		initial_term = NULL;
 
+	prefs = gtk_object_get_data (GTK_OBJECT (gtk_object_get_data(GTK_OBJECT(app), "term")), "prefs");
+	if (prefs)
+		gtk_object_destroy(GTK_OBJECT(prefs->prop_win));
+
 	gtk_widget_destroy (app);
 
 	if (terminals == NULL)
@@ -235,12 +257,7 @@ close_terminal_cmd (void *unused, void *data)
 {
 	GtkWidget *top = gtk_widget_get_toplevel (GTK_WIDGET (data));
 
-	terminals = g_list_remove (terminals, top);
-	if (top == initial_term)
-		initial_term = NULL;
-	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (data)));
-	if (terminals == NULL)
-		gtk_main_quit ();
+	close_app(top);
 }
 
 #if 0
@@ -495,6 +512,7 @@ load_config (char *class)
 	cfg->window_title = NULL;
 
 	cfg->termname = NULL;
+	cfg->terminal_id = 0;
 
 	cfg->update_records = ZVT_TERM_DO_UTMP_LOG|ZVT_TERM_DO_WTMP_LOG;
 
@@ -753,6 +771,7 @@ switch_terminal_class (ZvtTerm *term, struct terminal_config *newcfg)
 	gtk_widget_show (mbox);
 }
 
+/* this is the PREFS window destroy event ... */
 static void
 window_destroy (GtkWidget *w, gpointer data)
 {
@@ -1406,7 +1425,7 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	gtk_signal_connect (GTK_OBJECT (prefs->prop_win), "destroy",
 			    GTK_SIGNAL_FUNC (window_destroy), term);
 
-	help_entry.name = gnome_app_id;
+	help_entry.name = "gnome-terminal";
 	gtk_signal_connect (GTK_OBJECT (prefs->prop_win), "help",
 			    GTK_SIGNAL_FUNC (gnome_help_pbox_display),
 			    &help_entry);
@@ -1475,13 +1494,32 @@ void
 paste_cmd (GtkWidget *widget, ZvtTerm *term)
 {
 	GdkAtom string_atom;
-
+	GdkEvent *event;
+	gint32 time;
+	
 	string_atom = gdk_atom_intern ("STRING", FALSE);
 	if (string_atom == GDK_NONE)
 		return;
+
+	event = gtk_get_current_event ();
+	switch (event->type){
+	case GDK_BUTTON_PRESS:
+	case GDK_2BUTTON_PRESS:
+	case GDK_BUTTON_RELEASE:
+		time = event->button.time;
+		break;
+
+	case GDK_KEY_PRESS:
+	case GDK_KEY_RELEASE:
+		time = event->key.time;
+		break;
+
+	default:
+		time = GDK_CURRENT_TIME;
+	}
 	
 	gtk_selection_convert (GTK_WIDGET (term), GDK_SELECTION_PRIMARY, string_atom,
-			       GDK_CURRENT_TIME);
+			       time);
 }
 
 void
@@ -1614,7 +1652,10 @@ get_shell_name (char **shell, char **name, int isLogin)
 	g_assert (*shell != NULL);
 
 	only_name = strrchr (*shell, '/');
-	only_name++;
+	if (only_name != NULL)
+		only_name++;
+	else
+		only_name = *shell;
 	
 	if (isLogin){
 		len = strlen (only_name);
@@ -1633,7 +1674,7 @@ terminal_kill (GtkWidget *widget, void *data)
 {
 	GnomeApp *app = GNOME_APP (gtk_widget_get_toplevel (GTK_WIDGET (data)));
 
-	close_terminal_cmd (widget, app);
+	close_app (app);
 }
 
 /* called for "title_changed" event.  Use it to change the window title */
@@ -1939,7 +1980,7 @@ show_pty_error_dialog (int errcode)
 }
 
 GtkWidget *
-new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
+new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry, int termid)
 {
 	GtkWidget *app, *hbox, *scrollbar;
 	ZvtTerm   *term;
@@ -1958,6 +1999,8 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 
 	cfg = terminal_config_dup (cfg_in);
 
+	cfg->terminal_id = termid;
+
 	/* Setup the environment for the gnome-terminals:
 	 *
 	 * TERM is set to xterm (which is what zvt emulates)
@@ -2011,7 +2054,7 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	if (cfg->window_title) {
 	  gtk_window_set_title(GTK_WINDOW(app), cfg->window_title);
  	}
-	sprintf(winclass, "GnomeTerminal:%p", app);
+	sprintf(winclass, "GnomeTerminal.%d", termid);
 	gtk_window_set_wmclass (GTK_WINDOW (app), "GnomeTerminal", winclass);
 	gtk_window_set_policy(GTK_WINDOW (app), TRUE, TRUE, TRUE);
 
@@ -2083,8 +2126,8 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 				  GTK_SIGNAL_FUNC (set_hints), term);
 
 #ifdef ZVT_TERM_MATCH_SUPPORT
-	zvt_term_match_add( ZVT_TERM(term), "(((news|telnet|nttp|file|http|ftp)://)|(www|ftp))[-A-Za-z0-9\\.]+(:[0-9]*)?", VTATTR_UNDERLINE, "host only url");
-	zvt_term_match_add( ZVT_TERM(term), "(((news|telnet|nttp|file|http|ftp)://)|(www|ftp))[-A-Za-z0-9\\.]+(:[0-9]*)?/[-A-Za-z0-9_\\$\\.\\+\\!\\*\\(\\),;:@&=\\?/~\\#]*[^]'\\.}>\\) ,\\\"]", VTATTR_UNDERLINE, "full url");
+	zvt_term_match_add( ZVT_TERM(term), "(((news|telnet|nttp|file|http|ftp|https)://)|(www|ftp))[-A-Za-z0-9\\.]+(:[0-9]*)?", VTATTR_UNDERLINE, "host only url");
+	zvt_term_match_add( ZVT_TERM(term), "(((news|telnet|nttp|file|http|ftp|https)://)|(www|ftp))[-A-Za-z0-9\\.]+(:[0-9]*)?/[-A-Za-z0-9_\\$\\.\\+\\!\\*\\(\\),;:@&=\\?/~\\#]*[^]'\\.}>\\) ,\\\"]", VTATTR_UNDERLINE, "full url");
 #endif
 
 	if (!cfg->menubar_hidden)
@@ -2186,7 +2229,45 @@ new_terminal (GtkWidget *widget, ZvtTerm *term)
 
 	cfg = gtk_object_get_data (GTK_OBJECT (term), "config");
 
-	return new_terminal_cmd (NULL, cfg, NULL);
+	return new_terminal_cmd (NULL, cfg, NULL, terminal_id++);
+}
+
+GtkWidget *
+new_terminal_for_client (char *geom)
+{
+	if (terminals != 0)
+	{
+		ZvtTerm *term = ZVT_TERM (gtk_object_get_data
+					  (GTK_OBJECT(terminals->data),
+					   "term"));
+		struct terminal_config *cfg
+			= gtk_object_get_data (GTK_OBJECT (term), "config");
+		GtkWidget *w = new_terminal_cmd (NULL, cfg, geom ? geom
+						 : initial_global_geometry,
+						 terminal_id++);
+		return w;
+	}
+	else
+		return 0;
+}
+
+static void
+load_factory_settings ()
+{
+	gchar *buf;
+
+	buf = gnome_client_get_config_prefix (gnome_master_client ());
+	gnome_config_push_prefix (buf);
+
+	buf = g_strdup_printf ("factory/start=%d", start_terminal_factory);
+	start_terminal_factory = gnome_config_get_int (buf);
+	g_free (buf);
+
+	buf = g_strdup_printf ("factory/use=%d", use_terminal_factory);
+	use_terminal_factory = gnome_config_get_int (buf);
+	g_free (buf);
+
+	gnome_config_pop_prefix ();
 }
 
 static gboolean
@@ -2212,7 +2293,9 @@ load_session ()
 		char *class, *class_path;
 		int argc;
 		char *prefix = g_strdup_printf ("%s%d/", file, i);
-	  
+		int termid;
+		char termconf[16];
+
 		gnome_config_push_prefix (prefix);
 
 		/* NAUGHTY: The ICCCM requires that the WM stores
@@ -2243,10 +2326,17 @@ load_session ()
 		if (gnome_config_get_bool ("do_wtmp=true"))
 			cfg->update_records |= ZVT_TERM_DO_WTMP_LOG;
 
+		start_terminal_factory = gnome_config_get_bool ("start_terminal_factory=false");
+		use_terminal_factory = gnome_config_get_bool ("use_terminal_factory=false");
+
+		termid = gnome_config_get_int("terminal_id=-1");
+		if (termid!=-1)
+			terminal_id = termid;
+
 		g_free(class);
 		gnome_config_pop_prefix();
 
-		new_terminal_cmd (argv, cfg, geom);
+		new_terminal_cmd (argv, cfg, geom, terminal_id++);
 
 		g_free(cfg);
 		g_free (geom);
@@ -2319,6 +2409,7 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 		g_string_free (geom, TRUE);
 		
 		gnome_config_set_string("class", cfg->class);
+		gnome_config_set_int("terminal_id", cfg->terminal_id);
 		
 		if (top == initial_term){
 			int n;
@@ -2345,6 +2436,11 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 		gnome_config_set_bool("do_utmp", (cfg->update_records & ZVT_TERM_DO_UTMP_LOG) != 0);
 		gnome_config_set_bool("do_wtmp", (cfg->update_records & ZVT_TERM_DO_WTMP_LOG) != 0);
 
+		gnome_config_set_bool("start_terminal_factory", 
+				      start_terminal_factory);
+		gnome_config_set_bool("use_terminal_factory",
+				      use_terminal_factory);
+
 		gnome_config_pop_prefix ();
 		g_free (prefix);
 		
@@ -2352,6 +2448,8 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 	}
 	gnome_config_push_prefix (file);
 	gnome_config_set_int ("dummy/num_terms", i);
+	gnome_config_set_int ("factory/start", start_terminal_factory);
+	gnome_config_set_int ("factory/use", use_terminal_factory);
 	gnome_config_pop_prefix ();
 
 #if 0
@@ -2395,7 +2493,9 @@ enum {
 	DOWTMP_KEY   = -11,
 	DONOWTMP_KEY = -12,
         TITLE_KEY    = -13,
-	TERM_KEY     = -14
+	TERM_KEY     = -14,
+	START_FACTORY_KEY= -15,
+	USE_FACTORY_KEY  = -16
 };
 
 static struct poptOption cb_options [] = {
@@ -2446,6 +2546,12 @@ static struct poptOption cb_options [] = {
 	{ "termname", '\0', POPT_ARG_STRING, NULL, TERM_KEY,
           N_("Set the TERM variable"), N_("TERMNAME") },
 
+	{ "start-factory-server", '\0', POPT_ARG_NONE, NULL, START_FACTORY_KEY,
+	  N_("Try to start a TerminalFactory"), NULL },
+
+	{ "use-factory", '\0', POPT_ARG_NONE, NULL, USE_FACTORY_KEY,
+	  N_("Try to create the terminal with the TerminalFactory"), NULL },
+
 	{ NULL, '\0', 0, NULL, 0}
 };
 
@@ -2463,17 +2569,25 @@ parse_an_arg (poptContext state,
 	case CLASS_KEY:
 		free (cfg->class);
 		cfg->class = g_strconcat ("Class-", arg, NULL);
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case FONT_KEY:
 		cfg->font = (char *)arg;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case LOGIN_KEY:
 		cfg->invoke_as_login_shell = 1;
 		cmdline_login = TRUE;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case NOLOGIN_KEY:
 	        cfg->invoke_as_login_shell = 0;
 		cmdline_login = TRUE;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 	        break;
 	case GEOMETRY_KEY:
 		initial_global_geometry = (char *)arg;
@@ -2490,37 +2604,62 @@ parse_an_arg (poptContext state,
 				  x--;
 				  initial_command[x]=foo[x];
 			  }
+		
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 		  }
 	case FORE_KEY:
 		cfg->user_fore_str = arg;
 		cfg->have_user_colors = 1;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case BACK_KEY:
 		cfg->user_back_str = arg;
 		cfg->have_user_colors = 1;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case DOUTMP_KEY:
 		cfg->update_records_and &= ~ZVT_TERM_DO_UTMP_LOG;
 		cfg->update_records_xor |= ZVT_TERM_DO_UTMP_LOG;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case DONOUTMP_KEY:
 		cfg->update_records_and &= ~ZVT_TERM_DO_UTMP_LOG;
 		cfg->update_records_xor &= ~ZVT_TERM_DO_UTMP_LOG;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case DOWTMP_KEY:
 		cfg->update_records_and &= ~ZVT_TERM_DO_WTMP_LOG;
 		cfg->update_records_xor |= ZVT_TERM_DO_WTMP_LOG;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case DONOWTMP_KEY:
 		cfg->update_records_and &= ~ZVT_TERM_DO_WTMP_LOG;
 		cfg->update_records_xor &= ~ZVT_TERM_DO_WTMP_LOG;
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
 		break;
 	case TITLE_KEY:
 	        cfg->window_title = g_strdup(arg);
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
                 break;
 	case TERM_KEY:
 		cfg->termname = g_strdup_printf("TERM=%s", arg);
+		start_terminal_factory = FALSE;
+		use_terminal_factory = FALSE;
+		break;
+	case START_FACTORY_KEY:
+		start_terminal_factory = TRUE;
+		break;
+	case USE_FACTORY_KEY:
+		use_terminal_factory = TRUE;
 		break;
 	default:
 		break;
@@ -2542,6 +2681,8 @@ main_terminal_program (int argc, char *argv [], char **environ)
 	char *class;
 	struct terminal_config *default_config, *cmdline_config;
 	int i, j;
+	CORBA_ORB orb;
+	CORBA_Environment ev;
 
 	env = environ;
 	
@@ -2573,12 +2714,25 @@ main_terminal_program (int argc, char *argv [], char **environ)
 			initial_command[j]=NULL;
 			/* 'fool' popt into thinking we have less args */
 			argc=last;
+			use_terminal_factory = FALSE;
 			break;
 		}
 	}
-	
-	gnome_init_with_popt_table("Terminal", VERSION, argc, argv,
-				   cb_options, 0, NULL);
+
+	CORBA_exception_init (&ev);
+	orb = gnome_CORBA_init_with_popt_table ("Terminal", VERSION,
+						&argc, argv,
+						cb_options, 0, NULL,
+						0, &ev);
+	if (ev._major != CORBA_NO_EXCEPTION)
+	    exit (5);
+
+	CORBA_exception_free (&ev);
+
+	/* since -x gets stripped out of the commands, this
+	   will make it override --use-factory */
+	if (use_terminal_factory && initial_command)
+		use_terminal_factory = FALSE;
 
 	if(cmdline_config->user_back_str)
 		gdk_color_parse(cmdline_config->user_back_str,
@@ -2610,13 +2764,7 @@ main_terminal_program (int argc, char *argv [], char **environ)
 		else
 			class = g_strdup ("Config");
 	}
-	
-	client = gnome_master_client ();
-	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
-			    GTK_SIGNAL_FUNC (save_session), NULL);
-	gtk_signal_connect (GTK_OBJECT (client), "die",
-			    GTK_SIGNAL_FUNC (session_die), NULL);
-	
+			
 	{
 		char *prefix = g_strdup_printf ("Terminal/%s/", class);
 		gnome_config_push_prefix (prefix);
@@ -2655,13 +2803,53 @@ main_terminal_program (int argc, char *argv [], char **environ)
 	default_config->update_records ^= cmdline_config->update_records_xor;
 
 	terminal_config_free (cmdline_config);
+
+	load_factory_settings ();
+
+	if (start_terminal_factory) {
+		corba_init_server (orb);
+		if (!has_terminal_factory)
+			corba_activate_server ();
+	}
 	
-	if (!load_session ())
-		new_terminal_cmd (initial_command, default_config, initial_global_geometry);
+	if (!load_session ()) {
+		gboolean has_term = FALSE;
+		if (use_terminal_factory) {
+			CORBA_Environment ev;
+			CORBA_Object term;
+
+			CORBA_exception_init (&ev);
+			term = create_terminal_via_factory
+				(initial_global_geometry
+				 ? initial_global_geometry : "80x24", &ev);
+			if (ev._major != CORBA_NO_EXCEPTION)
+				exit (5);
+			if (term) {
+				CORBA_Object_release (term, &ev);
+				has_term = TRUE;
+			}
+			CORBA_exception_free (&ev);
+		}
+		if (!has_term) {
+			new_terminal_cmd (initial_command, default_config,
+					  initial_global_geometry,
+					  terminal_id++);
+		}
+	}
 
 	terminal_config_free (default_config);
 
+	if (!terminals)
+		return 0;
+
+	client = gnome_master_client ();
+	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
+			    GTK_SIGNAL_FUNC (save_session), NULL);
+	gtk_signal_connect (GTK_OBJECT (client), "die",
+			    GTK_SIGNAL_FUNC (session_die), NULL);
+
 	gtk_main ();
+
 	return 0;
 }
 
