@@ -89,7 +89,7 @@ enum {
   NSIGNALS2
 };
 
-static gint gsm_session_signals[NSIGNALS2];
+static guint gsm_session_signals[NSIGNALS2];
 static GtkObjectClass *parent_class = NULL;
 
 static void
@@ -131,15 +131,15 @@ gsm_session_object_init (GsmSession* session)
   session->waiting     = -1;
 }
 
-GtkTypeInfo gsm_session_info = 
+static GtkTypeInfo gsm_session_info = 
 {
   "GsmSession",
   sizeof (GsmSession),
   sizeof (GsmSessionClass),
   (GtkClassInitFunc) gsm_session_class_init,
   (GtkObjectInitFunc) gsm_session_object_init,
-  (GtkArgSetFunc) NULL,
-  (GtkArgGetFunc) NULL,
+  NULL,
+  NULL,
   (GtkClassInitFunc) NULL
 };
 
@@ -289,7 +289,7 @@ enum {
   NSIGNALS
 };
 
-static gint gsm_client_signals[NSIGNALS];
+static guint gsm_client_signals[NSIGNALS];
 static void client_reasons (GsmClient* client, gboolean confirm, 
 			    GSList* reasons);
 
@@ -374,8 +374,7 @@ GtkTypeInfo gsm_client_info =
   sizeof (GsmClientClass),
   (GtkClassInitFunc) gsm_client_class_init,
   (GtkObjectInitFunc) gsm_client_object_init,
-  (GtkArgSetFunc) NULL,
-  (GtkArgGetFunc) NULL,
+  NULL, NULL,
   (GtkClassInitFunc) NULL
 };
 
@@ -495,7 +494,7 @@ client_reasons (GsmClient* client, gboolean confirm, GSList* reasons)
   
   /* Hmm, may need to be override redirect as well since WMs are quite
      likely to be the source of the errors... */
-  //dialog = gnome_warning_dialog (message);
+  /* dialog = gnome_warning_dialog (message); */
   dialog = gnome_message_box_new (message, GNOME_MESSAGE_BOX_WARNING, NULL);
   gnome_dialog_append_button_with_pixmap (GNOME_DIALOG (dialog),
 					  _("Remove Program"),
@@ -528,7 +527,7 @@ enum {
   NSIGNALS3
 };
 
-static gint gsm_protocol_signals[NSIGNALS3];
+static guint gsm_protocol_signals[NSIGNALS3];
 
 static void
 gsm_protocol_class_init (GsmProtocolClass *klass)
@@ -567,8 +566,8 @@ GtkTypeInfo gsm_protocol_info =
   sizeof (GsmProtocolClass),
   (GtkClassInitFunc) gsm_protocol_class_init,
   (GtkObjectInitFunc) NULL,
-  (GtkArgSetFunc) NULL,
-  (GtkArgGetFunc) NULL,
+  NULL,
+  NULL,
   (GtkClassInitFunc) NULL
 };
 
@@ -649,6 +648,30 @@ gsm_protocol_get_last_session (GsmProtocol* protocol)
 			     GsmGetLastSession, NULL), NULL);  
 }
 
+void 
+gsm_protocol_set_trash_mode (GsmProtocol *protocol,
+			     gboolean     trash)
+{
+  SmProp prop;
+  SmPropValue vals[2];
+
+  g_return_if_fail(protocol != NULL);
+  g_return_if_fail(GSM_IS_PROTOCOL (protocol));
+
+  vals[0].length = strlen (GsmTrashMode);
+  vals[0].value = GsmTrashMode;
+
+  vals[1].length = 1;
+  vals[1].value = trash ? "1" : "0";
+
+  prop.name = GsmCommand;
+  prop.type = SmLISTofARRAY8;
+  prop.num_vals = 2;
+  prop.vals = vals;
+  
+  command (protocol, &prop, NULL);
+}
+
 /* Public utilities */
 gboolean   gsm_sh_quotes_balance (gchar* sh)
 {
@@ -729,7 +752,7 @@ dispatch_event (SmcConn smc_conn, SmPointer data,
 	  if (!strcmp (GSM_CLIENT_TYPE (props[0]), GsmProperty))
 	    {
 	      gint i;
-	      gchar *restart_command = NULL, *command = NULL;
+	      gchar *restart_command = NULL, *tmp_command = NULL;
 	      GsmClient* client = find_client (props[0], live_session);
 	      GsmSession* session = client->session;
 	      prop_free (props[0]);
@@ -756,35 +779,36 @@ dispatch_event (SmcConn smc_conn, SmPointer data,
 			}
 		      else if (!strcmp (name, SmCloneCommand))
 			{
-			  command = gsm_prop_to_sh (props[i]);
+			  tmp_command = gsm_prop_to_sh (props[i]);
 			}
 		      else if (!strcmp (name, SmRestartCommand))
 			{
 			  if (! command && ! client->command)
 			    {
 			      restart_command = gsm_prop_to_sh (props[i]);
-			      command = restart_command;
+			      tmp_command = restart_command;
 			    }
 			}
 		      prop_free (props[i]);
 		    }
 
-		  if (command)
+		  if (tmp_command)
 		    {		      
 		      gtk_signal_emit (GTK_OBJECT (client), 
 				       gsm_client_signals[COMMAND],
-				       command);
+				       tmp_command);
 		      if (! client->command && session->waiting)
 			{
 			  session->waiting--;
+			  g_message ("waiting is now: %d", session->waiting);
 			  if (!session->waiting)
 			    gtk_signal_emit (GTK_OBJECT (session),
 					     gsm_session_signals[INITIALIZED]);
 			}
 		      g_free (client->command);
-		      client->command = command;
+		      client->command = tmp_command;
 		      
-		      if (restart_command != command)
+		      if (restart_command != tmp_command)
 			g_free (restart_command);
 		    }
 		}
@@ -845,6 +869,8 @@ dispatch_event (SmcConn smc_conn, SmPointer data,
 			session->waiting = 1;
 		      else if (session->waiting)
 			session->waiting++;
+		      g_message ("waiting is now: %d", session->waiting);
+		      
 		    }
 		  prop_free (props[i]);
 		}
@@ -925,6 +951,7 @@ dispatch_event (SmcConn smc_conn, SmPointer data,
 		    session->waiting = 1;
 		  else if (session->waiting)
 		    session->waiting++;
+		  g_message ("waiting is now: %d", session->waiting);
 		  prop_free (props[i]);
 		}  
 	      reads = g_slist_remove (reads, session);
