@@ -20,11 +20,16 @@
 #include "mime.h"
 #include "misc.h"
 
+#include "gnome-helpwin.h" /* for statusMsg */
+
 static void convertMan(docObj obj);
 static void convertHTML(docObj obj);
-static void convertNone(docObj obj);
+static void convertAll(docObj obj);
 static void convertINFO(docObj obj);
+/*
 static void convertText(docObj obj);
+static void convertNone(docObj obj);
+*/
 
 void
 resolveMIME( docObj obj )
@@ -42,7 +47,7 @@ resolveMIME( docObj obj )
 	        docObjSetMimeType(obj, "application/x-info");
 	} else if (strstr(ref, "/man/")) {
 		docObjSetMimeType(obj, "application/x-troff-man");
-	} else if (strstr(ref, "html") || strstr(ref, "#")
+	} else if (strstr(ref, "htm") || strstr(ref, "#")
 		   || strstr(ref, "http")) {
 		docObjSetMimeType(obj, "text/html");
 	} else {
@@ -50,7 +55,6 @@ resolveMIME( docObj obj )
 	}
 
 	g_message("resolved mime type: %s", docObjGetMimeType(obj));
-
 }
 
 
@@ -67,10 +71,12 @@ convertMIME( docObj obj )
 		convertHTML(obj);
 	} else if (!strcmp(m, "application/x-info")) {
 		convertINFO(obj);
+#if 0
 	} else if (!strcmp(m, "text/plain")) {
 		convertText(obj);
+#endif
 	} else {
-		convertNone(obj);
+		convertAll(obj);
 	}
 }
 
@@ -91,6 +97,9 @@ convertHTML( docObj obj )
 	docObjSetConvData(obj, s, len, FALSE);
 }
 
+/* A assume these should be safe to delete but I dunno if
+   there are any "plans" for these -George */
+#if 0
 static void
 convertNone( docObj obj ) 
 {
@@ -123,6 +132,10 @@ convertText( docObj obj )
 	
 	docObjGetRawData(obj, &raw, &len);
 
+	/* Text conversion is not this easy -- you need to escape <, > and similar */
+
+	/* Text conversion is not this easy -- you need to escape <, > and similar */
+
 	s = g_malloc(len + 27);
 	memcpy(s, "<BODY><PRE>\n", 12);
 	memcpy(s + 12, raw, len);
@@ -130,6 +143,7 @@ convertText( docObj obj )
 
 	docObjSetConvData(obj, s, len + 27, TRUE);
 }
+#endif
 
 static void
 convertMan( docObj obj )
@@ -142,6 +156,7 @@ convertMan( docObj obj )
 	gint outbuflen;
 	gint i;
 
+	statusMsg("Calling gnome-man2html...");
 	/* if converted data exists lets use it */
 	docObjGetConvData(obj, &outbuf, &len);
 	if (outbuf)
@@ -175,6 +190,7 @@ convertINFO( docObj obj )
 	guchar *raw, *outbuf;
 	gint len, outbuflen;
 
+	statusMsg("Calling gnome-info2html...");
 	/* if converted data exists lets use it */
 	docObjGetConvData(obj, &outbuf, &outbuflen);
 	if (outbuf)
@@ -217,3 +233,31 @@ convertINFO( docObj obj )
 
 	g_free(basepath);
 }
+
+
+static void
+convertAll( docObj obj )
+{
+	char *argv[6];
+	guchar *raw, *outbuf;
+	gint len, outbuflen;
+
+	statusMsg("Calling external data conversion...");
+	/* if converted data exists lets use it */
+	docObjGetConvData(obj, &outbuf, &outbuflen);
+	if (outbuf)
+	    return;
+
+	argv[0] = "gnome-convert";
+	argv[1] = docObjGetMimeType(obj);
+	argv[2] = "text/html";
+	argv[3] = g_strdup(docObjGetAbsoluteRef(obj));
+	argv[4] = NULL;
+
+	g_message("filter: %s %s %s %s",
+		  argv[0],argv[1],argv[2],argv[3]);
+
+	docObjGetRawData(obj, &raw, &len);
+	getOutputFrom(argv, raw, len, &outbuf, &outbuflen);
+	docObjSetConvData(obj, outbuf, outbuflen, TRUE);
+}
