@@ -27,8 +27,8 @@ static GNOME_Panel panel_client = CORBA_OBJECT_NIL;
 
 #define APPLET_ID_KEY "applet_id_key"
 #define APPLET_WIDGET_KEY "applet_widget_key"
-#define pg_return_if_fail(x) if(!(x)) { g_print("type = %d exid = %s\n", ev._major, ev._repo_id); return; }
-#define pg_return_val_if_fail(x,y) if(!(x)) { g_print("type = %d exid = %s\n", ev._major, ev._repo_id); return y;}
+#define pg_return_if_fail(evp,x) {if(!(x)) { g_warning("file %s: line %d: Corba Exception: type = %d exid = %s\n", __FILE__, __LINE__, (evp)->_major, (evp)->_repo_id); return; }}
+#define pg_return_val_if_fail(evp,x,y) {if(!(x)) { g_warning("file %s: line %d: Corba Exception: type = %d exid = %s\n", __FILE__, __LINE__, (evp)->_major, (evp)->_repo_id); return y;}}
 
 typedef struct {
 	POA_GNOME_Applet		servant;
@@ -197,7 +197,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static int applet_widget_signals[LAST_SIGNAL] = {0};
+static guint applet_widget_signals[LAST_SIGNAL] = {0};
 
 static void
 marshal_signal_save (GtkObject * object,
@@ -741,27 +741,27 @@ gnome_panel_applet_corba_init(AppletWidget *applet, const char *goad_id)
 
 	POA_GNOME_Applet__init((POA_GNOME_Applet *)applet_servant, &ev);
 
-	pg_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
+	pg_return_val_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION, NULL);
 
 	applet_servant->poa = poa = (PortableServer_POA)
 		CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
 
 	PortableServer_POAManager_activate(PortableServer_POA__get_the_POAManager(poa, &ev), &ev);
-	pg_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
+	pg_return_val_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION, NULL);
 
 	applet_servant->objid =
 		PortableServer_POA_activate_object(poa, applet_servant,
 						   &ev);
-	pg_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
+	pg_return_val_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION, NULL);
 
 	applet_servant->obj = applet_obj =
 		PortableServer_POA_servant_to_reference(poa, applet_servant,
 							&ev);
-	pg_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
+	pg_return_val_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION, NULL);
 
 	goad_server_register(CORBA_OBJECT_NIL, applet_obj, goad_id,
 			     "server", &ev);
-	pg_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
+	pg_return_val_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION, NULL);
 
 	if (panel_client == CORBA_OBJECT_NIL) {
 		panel_client =
@@ -769,7 +769,10 @@ gnome_panel_applet_corba_init(AppletWidget *applet, const char *goad_id)
 							  "IDL:GNOME/Panel:1.0",
 							  0, NULL);
 
-		pg_return_val_if_fail (panel_client != CORBA_OBJECT_NIL, NULL);
+		if(panel_client == CORBA_OBJECT_NIL) {
+			g_warning(_("Cannot activate a panel object"));
+			return NULL;
+		}
 	}
 
 
@@ -789,7 +792,7 @@ gnome_panel_applet_corba_init(AppletWidget *applet, const char *goad_id)
 						       &privcfg,&globcfg,
 						       &applet_servant->winid,
 						       &ev);
-	pg_return_val_if_fail(ev._major == CORBA_NO_EXCEPTION, NULL);
+	pg_return_val_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION, NULL);
 
 	if(privcfg && *privcfg)
 		applet->privcfgpath = g_strdup(privcfg);
@@ -843,9 +846,12 @@ applet_widget_construct(AppletWidget* applet, const char *goad_id)
 	
 	g_return_if_fail(goad_id != NULL);
 
-	CD(applet) = corbadat = gnome_panel_applet_corba_init(applet,goad_id);
+	applet->corbadat = corbadat = gnome_panel_applet_corba_init(applet,goad_id);
 
-	g_return_if_fail(corbadat!=NULL);
+	if(!corbadat) {
+		g_warning(_("Cannot start CORBA"));
+		return;
+	}
 
 	gtk_plug_construct(GTK_PLUG(applet), corbadat->winid);
 	
@@ -1323,6 +1329,7 @@ server_applet_back_change(CustomAppletServant *servant,
 		pptr = backing->_u.pmap;
 		break;
 	default:
+		break;
 	}
 
 	if(servant->appwidget->frozen_level>0) {
@@ -1555,7 +1562,10 @@ server_applet_factory_create_object(AppletFactory *servant,
 	applet = servant->afunc(goad_id, (const char **)params->_buffer,
 				params->_length);
 
-	g_return_val_if_fail(applet, CORBA_OBJECT_NIL);
+	if(!applet) {
+		g_warning(_("Cannot create object"));
+		return CORBA_OBJECT_NIL;
+	}
 
 	return CORBA_Object_duplicate(CD(applet)->obj, ev);
 }
@@ -1595,10 +1605,10 @@ void applet_factory_new(const char *goad_id, AppletFactoryQuerier qfunc,
 	PortableServer_POAManager_activate
 		(PortableServer_POA__get_the_POAManager(poa, &ev), &ev);
 
-	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+	pg_return_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION);
 
 	f->objid = PortableServer_POA_activate_object(poa, f, &ev);
-	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
+	pg_return_if_fail(&ev, ev._major == CORBA_NO_EXCEPTION);
 
 	f->fobj = PortableServer_POA_servant_to_reference(poa, f, &ev);
 
