@@ -138,7 +138,7 @@ applet_menu_deactivate(GtkWidget *w, AppletInfo *info)
 }
 
 static AppletUserMenu *
-applet_get_callback(GList *user_menu, char *name)
+applet_get_callback(GList *user_menu, const char *name)
 {
 	GList *list;
 	for(list=user_menu;list!=NULL;list=g_list_next(list)) {
@@ -151,9 +151,9 @@ applet_get_callback(GList *user_menu, char *name)
 
 void
 applet_add_callback(AppletInfo *info,
-		    char *callback_name,
-		    char *stock_item,
-		    char *menuitem_text)
+		    const char *callback_name,
+		    const char *stock_item,
+		    const char *menuitem_text)
 {
 	AppletUserMenu *menu;
 
@@ -193,7 +193,7 @@ applet_add_callback(AppletInfo *info,
 }
 
 void
-applet_remove_callback(AppletInfo *info, char *callback_name)
+applet_remove_callback(AppletInfo *info, const char *callback_name)
 {
 	AppletUserMenu *menu;
 
@@ -226,7 +226,7 @@ applet_remove_callback(AppletInfo *info, char *callback_name)
 }
 
 void
-applet_callback_set_sensitive(AppletInfo *info, char *callback_name, int sensitive)
+applet_callback_set_sensitive(AppletInfo *info, const char *callback_name, int sensitive)
 {
 	AppletUserMenu *menu;
 
@@ -515,14 +515,17 @@ applet_destroy(GtkWidget *w, AppletInfo *info)
 	g_list_free(info->user_menu);
 }
 
-int
+gboolean
 register_toy(GtkWidget *applet,
 	     gpointer data,
 	     PanelWidget *panel,
 	     int pos,
+	     gboolean exactpos,
 	     AppletType type)
 {
 	AppletInfo *info;
+	int newpos;
+	gboolean insert_at_pos;
 	
 	g_return_val_if_fail(applet != NULL, FALSE);
 	g_return_val_if_fail(panel != NULL, FALSE);
@@ -574,18 +577,30 @@ register_toy(GtkWidget *applet,
 	applets_to_sync = TRUE;
 
 	/*add at the beginning if pos == -1*/
-	if(panel_widget_add_full(panel, applet, pos>=0?pos:0, TRUE,
-				 pos>=0?FALSE:TRUE)==-1) {
+	if(pos>=0) {
+		newpos = pos;
+		insert_at_pos = FALSE;
+	} else {
+		newpos = 0;
+		insert_at_pos = TRUE;
+	}
+	/* if exact pos is on then insert at that precise location */
+	if(exactpos)
+		insert_at_pos = TRUE;
+
+	if(panel_widget_add_full(panel, applet, newpos, TRUE,
+				 insert_at_pos)==-1) {
 		GSList *list;
 		for(list = panels; list != NULL; list = g_slist_next(list))
-			if(panel_widget_add_full(panel, applet, 0,TRUE,FALSE)!=-1)
+			if(panel_widget_add_full(panel, applet, 0,
+						 TRUE, TRUE)!=-1)
 				break;
 		if(!list) {
 			/*can't put it anywhere, clean up*/
 			gtk_widget_destroy(applet);
 			info->widget = NULL;
 			panel_clean_applet(info);
-			g_warning("Can't find an empty spot");
+			g_warning(_("Can't find an empty spot"));
 			return FALSE;
 		}
 		panel = PANEL_WIDGET(list->data);
