@@ -82,7 +82,7 @@ static GtkAdjustment *applet_padding;
 
 
 /* menu page */
-static GtkWidget *show_small_icons_cb;
+
 static GtkWidget *show_dot_buttons_cb;
 static GtkWidget *off_panel_popups_cb;
 static GtkWidget *hungry_menus_cb;
@@ -614,8 +614,6 @@ sync_menu_page_with_config(GlobalConfig *conf)
 {
 	MenuOptions *opt;
 	GtkWidget *w;
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(show_small_icons_cb),
-				    conf->show_small_icons);
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(show_dot_buttons_cb),
 				    conf->show_dot_buttons);
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(off_panel_popups_cb),
@@ -624,7 +622,6 @@ sync_menu_page_with_config(GlobalConfig *conf)
 				    conf->hungry_menus);
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(use_large_icons_cb),
 				    conf->use_large_icons);
-	gtk_widget_set_sensitive(use_large_icons_cb, conf->show_small_icons);
 
 	for (opt = menu_options; opt->inline_flag; ++opt) {
 		if (conf->menu_flags & opt->inline_flag)
@@ -641,8 +638,6 @@ static void
 sync_config_with_menu_page(GlobalConfig *conf)
 {
 	MenuOptions *opt;
-	conf->show_small_icons =
-		GTK_TOGGLE_BUTTON(show_small_icons_cb)->active;
 	conf->show_dot_buttons =
 		GTK_TOGGLE_BUTTON(show_dot_buttons_cb)->active;
 	conf->off_panel_popups =
@@ -688,12 +683,6 @@ add_menu_options (GtkTable *table, MenuOptions *opt, int row)
 			    GTK_SIGNAL_FUNC (changed_cb),  NULL);
 }
 
-static void
-toggle_sensitive (GtkWidget *t1, GtkWidget *t2)
-{
-	gtk_widget_set_sensitive (t2, GTK_TOGGLE_BUTTON (t1)->active);
-}
-
 static GtkWidget *
 menu_notebook_page(void)
 {
@@ -712,16 +701,10 @@ menu_notebook_page(void)
 	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 	
 	/* table for frame */
-	table = gtk_table_new(2,3,FALSE);
+	table = gtk_table_new(2,2,FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER (table), GNOME_PAD_SMALL);
 	gtk_container_add (GTK_CONTAINER (frame), table);
 	
-	/* Small Icons */
-	show_small_icons_cb = gtk_check_button_new_with_label (_("Show icons"));
-	gtk_signal_connect (GTK_OBJECT (show_small_icons_cb), "toggled", 
-			    GTK_SIGNAL_FUNC (changed_cb), NULL);
-	gtk_table_attach_defaults(GTK_TABLE(table),show_small_icons_cb, 0,1,0,1);
-
 	/* Dot Buttons */
 	show_dot_buttons_cb = gtk_check_button_new_with_label (_("Show [...] buttons"));
 	gtk_signal_connect (GTK_OBJECT (show_dot_buttons_cb), "toggled", 
@@ -732,7 +715,7 @@ menu_notebook_page(void)
 	off_panel_popups_cb = gtk_check_button_new_with_label (_("Show popup menus outside of panels"));
 	gtk_signal_connect (GTK_OBJECT (off_panel_popups_cb), "toggled", 
 			    GTK_SIGNAL_FUNC (changed_cb),  NULL);
-	gtk_table_attach_defaults(GTK_TABLE(table),off_panel_popups_cb, 0,1,2,3);
+	gtk_table_attach_defaults(GTK_TABLE(table),off_panel_popups_cb, 0,1,1,2);
 
 	/* Hungry Menus */
 	hungry_menus_cb = gtk_check_button_new_with_label (_("Keep menus in memory"));
@@ -744,10 +727,7 @@ menu_notebook_page(void)
 	use_large_icons_cb = gtk_check_button_new_with_label (_("Use large icons"));
 	gtk_signal_connect (GTK_OBJECT (use_large_icons_cb), "toggled",
 			    GTK_SIGNAL_FUNC (changed_cb), NULL);
-	gtk_signal_connect (GTK_OBJECT (show_small_icons_cb), "toggled",
-			    GTK_SIGNAL_FUNC (toggle_sensitive),
-			    use_large_icons_cb);
-	gtk_table_attach_defaults(GTK_TABLE(table),use_large_icons_cb, 0,1,1,2);
+	gtk_table_attach_defaults(GTK_TABLE(table),use_large_icons_cb, 0,1,0,1);
 
 	/* Menu frame */
 	frame = gtk_frame_new (_("Panel menu"));
@@ -1013,9 +993,6 @@ loadup_vals(void)
 	global_config.tooltips_enabled =
 		gnome_config_get_bool("tooltips_enabled=TRUE");
 
-	global_config.show_small_icons =
-		gnome_config_get_bool("show_small_icons=TRUE");
-
 	global_config.show_dot_buttons =
 		gnome_config_get_bool("show_dot_buttons=FALSE");
 
@@ -1148,8 +1125,6 @@ write_config(GlobalConfig *conf)
 			     (int)conf->movement_type);
 	gnome_config_set_bool("tooltips_enabled",
 			      conf->tooltips_enabled);
-	gnome_config_set_bool("show_small_icons",
-			      conf->show_small_icons);
 	gnome_config_set_bool("show_dot_buttons",
 			      conf->show_dot_buttons);
 	gnome_config_set_bool("hungry_menus",
