@@ -217,6 +217,8 @@ main(int argc, char **argv)
 
 	panel_tooltips = gtk_tooltips_new();
 
+	xstuff_init();
+
 	gnome_win_hints_init ();
 
 	/* read, convert and remove old config */
@@ -224,6 +226,8 @@ main(int argc, char **argv)
 
 	/*set the globals*/
 	load_up_globals();
+	/* this is so the capplet gets the right defaults */
+	write_global_config();
 
 	init_fr_chunks ();
 	
@@ -252,8 +256,6 @@ main(int argc, char **argv)
 	  starting multiple goad_id's at once are libgnorba's problem*/
 	load_queued_externs();
 
-	xstuff_init();
-
 	status_applet_create_offscreen();
 	
 	/* I use the glue code to avoid making this a C++ file */
