@@ -25,6 +25,16 @@
 
 static GSList *dir_list = NULL;
 
+static GMemChunk *file_chunk = NULL;
+static GMemChunk *dir_chunk = NULL;
+
+void
+init_fr_chunks ()
+{
+	file_chunk = g_mem_chunk_create (FileRec, 64, G_ALLOC_AND_FREE);
+	dir_chunk  = g_mem_chunk_create (DirRec,  16, G_ALLOC_AND_FREE);
+}
+
 /*reads in the order file and makes a list*/
 static GSList *
 get_presorted_from(char *dir)
@@ -79,25 +89,29 @@ get_applet_goad_id_from_dentry(GnomeDesktopEntry *ii)
 {
 	int i;
 	int constantlen = strlen("--activate-goad-server");
-	char *goad_id=NULL;
 
 	g_return_val_if_fail(ii!=NULL,NULL);
 
-	if (!ii->exec)
+	if (!ii->exec || !ii->type)
 		return NULL;
-	/*FIXME:
-	  this is a horrible horrible hack and should be taken out
-	  and shot, once we add proper way to do this*/
-	for(i=1;ii->exec[i];i++) {
-		if(strncmp("--activate-goad-server",
-			   ii->exec[i],constantlen)==0) {
-			if(strlen(ii->exec[i])>constantlen)
-				goad_id = g_strdup(&ii->exec[i][constantlen+1]);
-			else
-				goad_id = g_strdup(ii->exec[i+1]);
+	
+	if(strcmp(ii->type,"PanelApplet")==0) {
+		return g_strjoinv(" ",ii->exec);
+	} else {
+		/*this is here as a horrible hack since that's the way it
+		  used to work, but now one should make the .desktop type
+		  PanelApplet*/
+		for(i=1;ii->exec[i];i++) {
+			if(strncmp("--activate-goad-server",
+				   ii->exec[i],constantlen)==0) {
+				if(strlen(ii->exec[i])>constantlen)
+					return g_strdup(&ii->exec[i][constantlen+1]);
+				else
+					return g_strdup(ii->exec[i+1]);
+			}
 		}
 	}
-	return goad_id;
+	return NULL;
 }
 
 static void
@@ -125,7 +139,10 @@ fr_free(FileRec *fr, int free_fr)
 	}
 	if(free_fr) {
 		dir_list = g_slist_remove(dir_list,fr);
-		g_free(fr);
+		if (fr->type == FILE_REC_DIR)
+			g_chunk_free (fr, dir_chunk);
+		else
+			g_chunk_free (fr, file_chunk);
 	} else  {
 		if(fr->type == FILE_REC_DIR)
 			memset(fr,0,sizeof(DirRec));
@@ -147,7 +164,7 @@ fr_fill_dir(FileRec *fr, int sublevels)
 	g_return_if_fail(fr!=NULL);
 	g_return_if_fail(fr->name!=NULL);
 
-	ffr = g_new0(FileRec,1);
+	ffr = g_chunk_new0 (FileRec, file_chunk);
 	ffr->type = FILE_REC_EXTRA;
 	ffr->name = g_concat_dir_and_file(fr->name,".order");
 	ffr->parent = dr;
@@ -185,7 +202,7 @@ fr_fill_dir(FileRec *fr, int sublevels)
 
 			dentry = gnome_desktop_entry_load(name);
 			if(dentry) {
-				ffr = g_new0(FileRec,1);
+				ffr = g_chunk_new0 (FileRec, file_chunk);
 				ffr->type = FILE_REC_FILE;
 				ffr->name = name;
 				ffr->mtime = s.st_mtime;
@@ -218,8 +235,12 @@ fr_read_dir(DirRec *dr, char *mdir, struct stat *dstat, int sublevels)
 	g_return_val_if_fail(mdir!=NULL,NULL);
 
 	/*this will zero all fields*/
-	if(!dr)
-		dr = g_new0(DirRec,1);
+	if(!dr) {
+		dr = g_chunk_new0 (DirRec, dir_chunk);
+		/* this must be set otherwise we may messup on
+		   fr_free */
+		dr->frec.type = FILE_REC_DIR;
+	}
 	fr = (FileRec *)dr;
 
 	if(fr->last_stat < curtime-1) {
@@ -330,8 +351,10 @@ fr_check_and_reread(FileRec *fr)
 				ddr = (DirRec *)ffr;
 				p = g_concat_dir_and_file(ffr->name,
 							  ".directory");
-				if (ddr->dentrylast_stat >= curtime-1)
+				if (ddr->dentrylast_stat >= curtime-1) {
+					g_free (p);
 					break;
+				}
 				if(stat(p,&s)==-1) {
 					if(dr->dentrymtime) {
 						g_free(ffr->icon);
