@@ -57,6 +57,8 @@ static void
 update_position_toggles (PerPanelConfig *ppc)
 {
 	GtkWidget *toggle = ppc->toggle[ppc->edge][ppc->align];
+	/* this could happen during type changes */
+	if(!toggle) return;
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle), TRUE);
 }
 
@@ -108,6 +110,8 @@ update_config_size(GtkWidget *panel)
 	PerPanelConfig *ppc = get_config_struct(panel);
 	int i;
 	PanelWidget *p;
+	GtkWidget *menuitem;
+
 	if(!ppc)
 		return;
 	p = PANEL_WIDGET(BASEP_WIDGET(panel)->panel);
@@ -131,8 +135,8 @@ update_config_size(GtkWidget *panel)
 	}
 	
 	gtk_option_menu_set_history (GTK_OPTION_MENU (ppc->size_menu), i);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ppc->size_menu_items[i]),
-				       TRUE);
+	menuitem = g_list_nth_data(GTK_MENU_SHELL(GTK_OPTION_MENU(ppc->size_menu)->menu)->children, i);
+	gtk_menu_item_activate(GTK_MENU_ITEM(menuitem));
 }
 
 void
@@ -174,10 +178,8 @@ update_config_back(PanelWidget *pw)
 		break;
 	}
 
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item),
-				       TRUE);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om),
-				    history);
+	gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om), history);
+	gtk_menu_item_activate(GTK_MENU_ITEM(item));
 }
 
 void
@@ -220,6 +222,7 @@ update_config_align (BasePWidget *w)
 	update_position_toggles (ppc);
 }
 
+
 static void
 config_destroy(GtkWidget *widget, gpointer data)
 {
@@ -538,7 +541,8 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 
 	update_position_toggles (ppc);
 
-	w = gtk_viewport_new (NULL, NULL);
+	w = gtk_frame_new (NULL);
+	gtk_frame_set_shadow_type(GTK_FRAME(w), GTK_SHADOW_IN);
 	gtk_table_attach (GTK_TABLE (table), w, 
 			  1, 1 + aligns,
 			  1, 1 + aligns,
@@ -787,7 +791,7 @@ size_set_size (GtkWidget *widget, gpointer data)
 	int sz = GPOINTER_TO_INT(data);
 	PerPanelConfig *ppc = gtk_object_get_user_data(GTK_OBJECT(widget));
 
-	if(!GTK_CHECK_MENU_ITEM(widget)->active)
+	if(ppc->sz == sz)
 		return;
 
 	ppc->sz = sz;
@@ -795,6 +799,16 @@ size_set_size (GtkWidget *widget, gpointer data)
 	REGISTER_CHANGES (ppc);
 }
 
+/* XXX: until this is fixed in GTK+ */
+static void
+activate_proper_item (GtkMenu *menu)
+{
+	GtkWidget *active;
+	active = gtk_menu_get_active(menu);
+	if(active)
+		gtk_menu_item_activate(GTK_MENU_ITEM(active));
+}
+
 static GtkWidget *
 make_size_widget (PerPanelConfig *ppc)
 {
@@ -803,7 +817,6 @@ make_size_widget (PerPanelConfig *ppc)
 	GtkWidget *menu;
 	GtkWidget *menuitem;
 	GtkWidget *w;
-	GSList *group;
 	gchar *s;
 	int i;
 
@@ -819,62 +832,47 @@ make_size_widget (PerPanelConfig *ppc)
 
 	
 	menu = gtk_menu_new ();
+	gtk_signal_connect (GTK_OBJECT (menu), "deactivate", 
+			    GTK_SIGNAL_FUNC (activate_proper_item), 
+			    NULL);
 
-	ppc->size_menu_items[0] = menuitem =
-		gtk_radio_menu_item_new_with_label (NULL,
-						    _("Tiny (24 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("Tiny (24 pixels)"));
 	gtk_widget_show(menuitem);
 	gtk_menu_append (GTK_MENU (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "toggled",
+	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 			    GTK_SIGNAL_FUNC (size_set_size),
 			    GINT_TO_POINTER (SIZE_TINY));
 	
-	group = gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(menuitem));
-
-	ppc->size_menu_items[1] = menuitem =
-		gtk_radio_menu_item_new_with_label (group,
-						    _("Small (36 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("Small (36 pixels)"));
 	gtk_widget_show(menuitem);
 	gtk_menu_append (GTK_MENU (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "toggled",
+	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 			    GTK_SIGNAL_FUNC (size_set_size),
 			    GINT_TO_POINTER (SIZE_SMALL));
 	
-	group = gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(menuitem));
-
-	ppc->size_menu_items[2] = menuitem =
-		gtk_radio_menu_item_new_with_label (group,
-						    _("Standard (48 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("Standard (48 pixels)"));
 	gtk_widget_show(menuitem);
 	gtk_menu_append (GTK_MENU (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "toggled",
+	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 			    GTK_SIGNAL_FUNC (size_set_size),
 			    GINT_TO_POINTER (SIZE_STANDARD));
 
-	group = gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(menuitem));
-
-	ppc->size_menu_items[3] = menuitem =
-		gtk_radio_menu_item_new_with_label (group,
-						    _("Large (64 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("Large (64 pixels)"));
 	gtk_widget_show(menuitem);
 	gtk_menu_append (GTK_MENU (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "toggled",
+	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 			    GTK_SIGNAL_FUNC (size_set_size),
 			    GINT_TO_POINTER (SIZE_LARGE));
 
-	group = gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(menuitem));
-
-	ppc->size_menu_items[4] = menuitem =
-		gtk_radio_menu_item_new_with_label (group,
-						    _("Huge (80 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("Huge (80 pixels)"));
 	gtk_widget_show(menuitem);
 	gtk_menu_append (GTK_MENU (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "toggled",
+	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
 			    GTK_SIGNAL_FUNC (size_set_size),
 			    GINT_TO_POINTER (SIZE_HUGE));
 
@@ -912,8 +910,8 @@ make_size_widget (PerPanelConfig *ppc)
 	}
 
 	gtk_option_menu_set_history (GTK_OPTION_MENU (ppc->size_menu), i);
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ppc->size_menu_items[i]),
-				       TRUE);
+	menuitem = g_list_nth_data(GTK_MENU_SHELL(GTK_OPTION_MENU(ppc->size_menu)->menu)->children, i);
+	gtk_menu_item_activate(GTK_MENU_ITEM(menuitem));
 
 	return vbox;
 }
@@ -975,7 +973,7 @@ set_back (GtkWidget *widget, gpointer data)
 	PerPanelConfig *ppc = gtk_object_get_user_data(GTK_OBJECT(widget));
 	PanelBackType back_type = GPOINTER_TO_INT(data);
 
-	if(!GTK_CHECK_MENU_ITEM(widget)->active)
+	if(ppc->back_type == back_type)
 		return;
 
 	pixf = gtk_object_get_data(GTK_OBJECT(widget),"pix");
@@ -997,14 +995,12 @@ set_back (GtkWidget *widget, gpointer data)
 	REGISTER_CHANGES (ppc);
 }
 
-
 static GtkWidget *
 background_page (PerPanelConfig *ppc)
 {
 	GtkWidget *box, *f, *t;
 	GtkWidget *vbox, *noscale, *fit, *strech;
 	GtkWidget *w, *m;
-	GSList *group;
 
 	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_container_set_border_width(GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
@@ -1017,17 +1013,18 @@ background_page (PerPanelConfig *ppc)
 
 	/*background type option menu*/
 	m = gtk_menu_new ();
-	ppc->non = gtk_radio_menu_item_new_with_label (NULL, _("Standard"));
+	gtk_signal_connect (GTK_OBJECT (m), "deactivate", 
+			    GTK_SIGNAL_FUNC (activate_proper_item), 
+			    NULL);
+	ppc->non = gtk_menu_item_new_with_label (_("Standard"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->non),ppc);
 	gtk_widget_show (ppc->non);
 	gtk_menu_append (GTK_MENU (m), ppc->non);
-	group = gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(ppc->non));
-	ppc->col = gtk_radio_menu_item_new_with_label (group, _("Color"));
+	ppc->col = gtk_menu_item_new_with_label (_("Color"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->col),ppc);
 	gtk_widget_show (ppc->col);
 	gtk_menu_append (GTK_MENU (m), ppc->col);
-	group = gtk_radio_menu_item_group(GTK_RADIO_MENU_ITEM(ppc->col));
-	ppc->pix = gtk_radio_menu_item_new_with_label (group, _("Pixmap"));
+	ppc->pix = gtk_menu_item_new_with_label (_("Pixmap"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->pix),ppc);
 	gtk_widget_show (ppc->pix);
 	gtk_menu_append (GTK_MENU (m), ppc->pix);
@@ -1124,33 +1121,78 @@ background_page (PerPanelConfig *ppc)
 			    GTK_SIGNAL_FUNC (set_rotate_pixmap_bg), ppc);
 	gtk_box_pack_start (GTK_BOX (box), w, FALSE, FALSE,0);
 
-	gtk_signal_connect (GTK_OBJECT (ppc->non), "toggled", 
+	gtk_signal_connect (GTK_OBJECT (ppc->non), "activate", 
 			    GTK_SIGNAL_FUNC (set_back), 
 			    GINT_TO_POINTER(PANEL_BACK_NONE));
-	gtk_signal_connect (GTK_OBJECT (ppc->pix), "toggled", 
+	gtk_signal_connect (GTK_OBJECT (ppc->pix), "activate", 
 			    GTK_SIGNAL_FUNC (set_back), 
 			    GINT_TO_POINTER(PANEL_BACK_PIXMAP));
-	gtk_signal_connect (GTK_OBJECT (ppc->col), "toggled", 
+	gtk_signal_connect (GTK_OBJECT (ppc->col), "activate", 
 			    GTK_SIGNAL_FUNC (set_back), 
 			    GINT_TO_POINTER(PANEL_BACK_COLOR));
 	
 	if(ppc->back_type == PANEL_BACK_NONE) {
 		gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om), 0);
-		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ppc->non),
-					       TRUE);
+		gtk_menu_item_activate(GTK_MENU_ITEM(ppc->non));
 	} else if(ppc->back_type == PANEL_BACK_COLOR) {
 		gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om), 1);
-		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ppc->col),
-					       TRUE);
+		gtk_menu_item_activate(GTK_MENU_ITEM(ppc->col));
 	} else {
 		gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om), 2);
-		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ppc->pix),
-					       TRUE);
+		gtk_menu_item_activate(GTK_MENU_ITEM(ppc->pix));
 	}
 
 	return vbox;
 }
 
+void
+update_config_type (BasePWidget *w)
+{
+	PerPanelConfig *ppc = get_config_struct (GTK_WIDGET (w));
+	int i,j;
+	GtkWidget *page;
+
+	if (!ppc)
+		return;
+
+	g_return_if_fail(ppc->type_tab);
+
+	ppc->register_changes = FALSE;
+	gtk_widget_destroy(GTK_BIN(ppc->type_tab)->child);
+
+	/*FIXME: magic numbers */
+	for(i=0;i<4;i++)
+		for(j=0;j<3;j++)
+			ppc->toggle[i][j] = NULL;
+	if(IS_EDGE_WIDGET(w)) {
+		/* edge notebook page */
+		page = edge_notebook_page(ppc);
+		gtk_label_set(GTK_LABEL(ppc->type_tab_label),
+			      _("Edge panel"));
+		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
+	} else if(IS_ALIGNED_WIDGET(w)) {
+		/* aligned notebook page */
+		page = aligned_notebook_page(ppc);
+		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
+		gtk_label_set(GTK_LABEL(ppc->type_tab_label),
+			      _("Aligned panel"));
+	} else if(IS_SLIDING_WIDGET(w)) {
+		/* sliding notebook page */
+		page = sliding_notebook_page(ppc);
+		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
+		gtk_label_set(GTK_LABEL(ppc->type_tab_label),
+			      _("Sliding panel"));
+	} else if(IS_FLOATING_WIDGET(w)) {
+		/* floating notebook page */
+		page = floating_notebook_page(ppc);
+		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
+		gtk_label_set(GTK_LABEL(ppc->type_tab_label),
+			      _("Floating panel"));
+ 	}
+	gtk_widget_show_all(ppc->type_tab);
+	ppc->register_changes = TRUE;
+}
+
 static void
 panelcfg_help(void)
 {
@@ -1238,34 +1280,49 @@ panel_config(GtkWidget *panel)
 
 	if(IS_EDGE_WIDGET(panel)) {
 		/* edge notebook page */
-		page = edge_notebook_page (ppc);
-		gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
-					  page,
-					  gtk_label_new (_("Edge panel")));
+		page = edge_notebook_page(ppc);
+		ppc->type_tab = gtk_event_box_new();
+		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
+		ppc->type_tab_label = gtk_label_new (_("Edge panel"));
+		gtk_notebook_append_page(GTK_NOTEBOOK(prop_nbook),
+					 ppc->type_tab,
+					 ppc->type_tab_label);
 	} else if(IS_ALIGNED_WIDGET(panel)) {
 		/* aligned notebook page */
-		page = aligned_notebook_page (ppc);
-		gtk_notebook_append_page (GTK_NOTEBOOK(prop_nbook),
-					  page,
-					  gtk_label_new (_("Aligned panel")));
-	}else if (IS_SLIDING_WIDGET (panel)) {
+		page = aligned_notebook_page(ppc);
+		ppc->type_tab = gtk_event_box_new();
+		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
+		ppc->type_tab_label = gtk_label_new (_("Aligned panel"));
+		gtk_notebook_append_page(GTK_NOTEBOOK(prop_nbook),
+					 ppc->type_tab,
+					 ppc->type_tab_label);
+	} else if(IS_SLIDING_WIDGET(panel)) {
 		/* sliding notebook page */
-		page = sliding_notebook_page (ppc);
-		gtk_notebook_append_page (GTK_NOTEBOOK (prop_nbook),
-					  page,
-					  gtk_label_new (_("Sliding panel")));
-	} else if (IS_FLOATING_WIDGET (panel)) {
+		page = sliding_notebook_page(ppc);
+		ppc->type_tab = gtk_event_box_new();
+		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
+		ppc->type_tab_label = gtk_label_new (_("Sliding panel"));
+		gtk_notebook_append_page(GTK_NOTEBOOK (prop_nbook),
+					 ppc->type_tab,
+					 ppc->type_tab_label);
+	} else if(IS_FLOATING_WIDGET(panel)) {
 		/* floating notebook page */
-		page = floating_notebook_page (ppc);
-		gtk_notebook_append_page (GTK_NOTEBOOK (prop_nbook),
-					  page,
-					  gtk_label_new (_("Floating panel")));
+		page = floating_notebook_page(ppc);
+		ppc->type_tab = gtk_event_box_new();
+		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
+		ppc->type_tab_label = gtk_label_new (_("Floating panel"));
+		gtk_notebook_append_page(GTK_NOTEBOOK (prop_nbook),
+					 ppc->type_tab,
+					 ppc->type_tab_label);
 	} else if(IS_DRAWER_WIDGET(panel)) {
 		BasePWidget *basep = BASEP_WIDGET(panel);
 		GtkWidget *applet = PANEL_WIDGET(basep->panel)->master_widget;
 		AppletInfo *info =
 			gtk_object_get_data(GTK_OBJECT(applet), "applet_info");
 		add_drawer_properties_page(ppc, info->data);
+
+		/* we can't change to/from drawers anyhow */
+		ppc->type_tab = NULL;
  	}
 
 	/* Backing configuration */
